==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/InputBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentValueChangedEventArgs } from "./ComponentValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
import { InputBaseDirection_$type } from "./InputBaseDirection";
import { InputBaseSelectMode_$type } from "./InputBaseSelectMode";
/**
 * @hidden
 */
var InputBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(InputBase, _super);
    function InputBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = new WCNativeHelper();
        _this.k = null;
        _this.inputOcurred = null;
        _this.focus = null;
        _this.blur = null;
        return _this;
    }
    Object.defineProperty(InputBase.prototype, "f", {
        get: function () {
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "nativeElement", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e.n = this.k;
        },
        enumerable: false,
        configurable: true
    });
    InputBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(InputBase.prototype, "n", {
        get: function () {
            var ret_ = this.f.m("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "h", {
        get: function () {
            var ret_ = this.f.m("outlined");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("outlined", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "j", {
        get: function () {
            var ret_ = this.f.m("required");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("required", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "g", {
        get: function () {
            var ret_ = this.f.m("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "i", {
        get: function () {
            var ret_ = this.f.m("readonly");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("readonly", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "o", {
        get: function () {
            var ret_ = this.f.m("placeholder");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("placeholder", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "m", {
        get: function () {
            var ret_ = this.f.m("label");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("label", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "b", {
        get: function () {
            var ret_ = this.f.m("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.f.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    InputBase.prototype.inputOcurredChanged = function () {
        var _this = this;
        if (this.inputOcurred != null) {
            this.f.q("input", function (a) { return _this.inputOcurred(_this, ComponentValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.t("input");
        }
    };
    InputBase.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.f.q("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.t("focus");
        }
    };
    InputBase.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.f.q("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.t("blur");
        }
    };
    InputBase.prototype.r = function () {
        this.nativeElement.connectedCallback();
    };
    InputBase.prototype.y = function (a) {
        this.nativeElement.themeAdopted(this.f.h(a));
    };
    InputBase.prototype.t = function (a) {
        this.nativeElement.focus(this.f.h(a));
    };
    InputBase.prototype.q = function () {
        this.nativeElement.blur();
    };
    InputBase.prototype.x = function (a, b, c) {
        this.nativeElement.setSelectionRange(this.f.h(a), this.f.h(b), this.f.h(enumGetBox(InputBaseDirection_$type, c)));
    };
    InputBase.prototype.w = function (a, b, c, d) {
        this.nativeElement.setRangeText(this.f.h(a), this.f.h(b), this.f.h(c), this.f.h(enumGetBox(InputBaseSelectMode_$type, d)));
    };
    InputBase.$t = markType(InputBase, 'InputBase', BaseElement.$);
    return InputBase;
}(BaseElement));
export { InputBase };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/InputBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentValueChangedEventArgs } from "./ComponentValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
import { InputBaseDirection_$type } from "./InputBaseDirection";
import { InputBaseSelectMode_$type } from "./InputBaseSelectMode";
/**
 * @hidden
 */
var InputBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(InputBase, _super);
    function InputBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = new WCNativeHelper();
        _this.k = null;
        _this.inputOcurred = null;
        _this.focus = null;
        _this.blur = null;
        return _this;
    }
    Object.defineProperty(InputBase.prototype, "f", {
        get: function () {
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "nativeElement", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e.o = this.k;
        },
        enumerable: false,
        configurable: true
    });
    InputBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(InputBase.prototype, "n", {
        get: function () {
            var ret_ = this.f.n("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "h", {
        get: function () {
            var ret_ = this.f.n("outlined");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("outlined", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "j", {
        get: function () {
            var ret_ = this.f.n("required");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("required", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "g", {
        get: function () {
            var ret_ = this.f.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "i", {
        get: function () {
            var ret_ = this.f.n("readonly");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("readonly", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "o", {
        get: function () {
            var ret_ = this.f.n("placeholder");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("placeholder", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "m", {
        get: function () {
            var ret_ = this.f.n("label");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("label", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "b", {
        get: function () {
            var ret_ = this.f.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.f.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    InputBase.prototype.inputOcurredChanged = function () {
        var _this = this;
        if (this.inputOcurred != null) {
            this.f.r("input", function (a) { return _this.inputOcurred(_this, ComponentValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.u("input");
        }
    };
    InputBase.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.f.r("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.u("focus");
        }
    };
    InputBase.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.f.r("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.u("blur");
        }
    };
    InputBase.prototype.r = function () {
        this.nativeElement.connectedCallback();
    };
    InputBase.prototype.y = function (a) {
        this.nativeElement.themeAdopted(this.f.i(a));
    };
    InputBase.prototype.t = function (a) {
        this.nativeElement.focus(this.f.i(a));
    };
    InputBase.prototype.q = function () {
        this.nativeElement.blur();
    };
    InputBase.prototype.x = function (a, b, c) {
        this.nativeElement.setSelectionRange(this.f.i(a), this.f.i(b), this.f.i(enumGetBox(InputBaseDirection_$type, c)));
    };
    InputBase.prototype.w = function (a, b, c, d) {
        this.nativeElement.setRangeText(this.f.i(a), this.f.i(b), this.f.i(c), this.f.i(enumGetBox(InputBaseSelectMode_$type, d)));
    };
    InputBase.$t = markType(InputBase, 'InputBase', BaseElement.$);
    return InputBase;
}(BaseElement));
export { InputBase };
